@@ -22,10 +22,11 @@ this module can be modified.
 import contextlib
 import datetime
 import inspect
+import os
 import threading
 import warnings
 from enum import Enum, IntEnum, unique
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Optional
 
 import attr
 
@@ -139,7 +140,7 @@ class settings(metaclass=settingsMeta):
         else:
             raise AttributeError("settings has no attribute %s" % (name,))
 
-    def __init__(self, parent: "settings" = None, **kwargs: Any) -> None:
+    def __init__(self, parent: Optional["settings"] = None, **kwargs: Any) -> None:
         if parent is not None and not isinstance(parent, settings):
             raise InvalidArgument(
                 "Invalid argument: parent=%r is not a settings instance" % (parent,)
@@ -290,7 +291,9 @@ class settings(metaclass=settingsMeta):
         return ", ".join(sorted(bits, key=len))
 
     @staticmethod
-    def register_profile(name: str, parent: "settings" = None, **kwargs: Any) -> None:
+    def register_profile(
+        name: str, parent: Optional["settings"] = None, **kwargs: Any,
+    ) -> None:
         """Registers a collection of values to be used as a settings profile.
 
         Settings profiles can be loaded by name - for example, you might
@@ -379,13 +382,15 @@ settings._define_setting(
     default=False,
     options=(True, False),
     description="""
-If this is True then hypothesis will run in deterministic mode
-where each falsification uses a random number generator that is seeded
-based on the hypothesis to falsify, which will be consistent across
-multiple runs. This has the advantage that it will eliminate any
-randomness from your tests, which may be preferable for some situations.
-It does have the disadvantage of making your tests less likely to
-find novel breakages.
+If True, seed Hypothesis' random number generator using a hash of the test
+function, so that every run will test the same set of examples until you
+update Hypothesis, Python, or the test function.
+
+This allows you to `check for regressions and look for bugs
+<https://blog.nelhage.com/post/two-kinds-of-testing/>`__ using
+:ref:`separate settings profiles <settings_profiles>` - for example running
+quick deterministic tests on every commit, and a longer non-deterministic
+nightly testing run.
 """,
 )
 
@@ -607,13 +612,21 @@ Set this to None to disable this behaviour entirely.
 )
 
 
+def is_in_ci() -> bool:
+    # GitHub Actions, Travis CI and AppVeyor have "CI"
+    # Azure Pipelines has "TF_BUILD"
+    return "CI" in os.environ or "TF_BUILD" in os.environ
+
+
 settings._define_setting(
     "print_blob",
-    default=False,
+    default=is_in_ci(),
+    show_default=False,
     options=(True, False),
     description="""
 If set to ``True``, Hypothesis will print code for failing examples that can be used with
 :func:`@reproduce_failure <hypothesis.reproduce_failure>` to reproduce the failing example.
+The default is ``True`` if the ``CI`` or ``TF_BUILD`` env vars are set, ``False`` otherwise.
 """,
 )
 
